// BookmarkDlg.h
// (c) 2003-2004 exeal

#ifndef _BOOKMARK_DLG_H_
#define _BOOKMARK_DLG_H_
#include "..\Manah\Dialog.h"
#include "Alpha.h"
#include <map>


namespace Alpha {

class CAlphaApp;

// CBookmarkDlg class definition
/////////////////////////////////////////////////////////////////////////////

///	[ubN}[N] _CAO
class CBookmarkDlg : public CDialog {
	// RXgN^
public:
	CBookmarkDlg(const CAlphaApp& app);

	// \bh
public:
	void	UpdateList();
protected:
	void	GetItemInfo(unsigned long iItem, wstring& strFileName, length_t& iLine) const;
	void	OnBtnDelete();

	// bZ[Wnh
protected:
	virtual bool	OnCommand(WORD wID, WORD wNotifyCode, HWND hwndCtrl);	// WM_COMMAND
	virtual bool	OnInitDialog(HWND hwndFocus, LPARAM lInitParam);		// WM_INITDIALOG
	virtual bool	OnNotify(int idCtrl, LPNMHDR lpNMHDR);					// WM_NOTIFY
	virtual void	OnOK();													// IDOK

	// f[^o
private:
	const CAlphaApp&			m_app;
	map<wstring, unsigned int>	m_mapTabIndex;	// t@C -> ^uԍ
};

}

#endif /* _BOOKMARK_DLG_H_ */

/* [EOF] */